"""
Overview:
    todo

Usage:
  m3 new <name>
  m3 vis
  m3 hi

Options:
  -h, --help                        : show this help message
      --name=<name>                 : [default: general]
"""

import logging

from docopt import docopt
from flask import Flask, render_template

from .generate_template import generate_template

app = Flask(__name__)
logging.basicConfig(level=logging.DEBUG, format="[%(levelname)s]: %(message)s")


@app.route('/')
def index():
    return render_template('index.html')


def main():
    args = docopt(__doc__)
    print(args)
    if args['new']:
        generate_template(args['<name>'])
    elif args['vis']:
        app.run(host='0.0.0.0', port=5000)
    elif args['hi']:
        print("hello!")


if __name__ == "__main__":
    main()



import logging
import os
from typing import List

from .const import CONST


def generate_template(name: str) -> None:
    # ディレクトリ作成
    # コンテストとの紐付け
    # testerの取得

    logger = logging.getLogger(__name__)
    logger.info(f"start generating template as '{name}'")

    if os.path.exists(name):
        logger.error(f"a directory named '{name}' is already exists.")
        return

    os.makedirs(name)

    predicted_contests_name = predict_related_contests(name)
    for pcn in predicted_contests_name:
        is_for_the_contest = input(f"\nthis template will be used for '{pcn}'?  [y/n]: ").strip() == "y"
        print()

    logger.info("creation successful!")


def predict_related_contests(name) -> List[str]:
    # name, url, period, in progress,
    logger = logging.getLogger(__name__)
    logger.debug(CONST.AtCoderContestsURL)

    return ["AtCoder Heuristic Contest 001"]





import dataclasses


@dataclasses.dataclass(frozen=True)
class __CONST:
    AtCoderContestsURL = "https://atcoder.jp/contests/"
    AtCoderPastMarathonContestsURL = "https://atcoder.jp/contests/archive?ratedType=0&category=1200"


CONST = __CONST()







# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['marathon_matches_manager']

package_data = \
{'': ['*'], 'marathon_matches_manager': ['static/*', 'templates/*']}

install_requires = \
['Flask>=2.0.3,<3.0.0', 'docopt>=0.6.2,<0.7.0']

entry_points = \
{'console_scripts': ['m3 = marathon_matches_manager.m3:main']}

setup_kwargs = {
    'name': 'marathon-matches-manager',
    'version': '0.1.1',
    'description': '',
    'long_description': None,
    'author': 'kryInit',
    'author_email': 'kryinit@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
